@@ -1,7 +1,7 @@
 import networkx as nx
-import numpy as np
 from networkx.algorithms import bipartite
 from collections import defaultdict
+from gratelpy.utils import invert_dict
 
 def get_valid_path_graph_cycles(path_graph):
     # path_graph: digraph with nodes = paths & edge n1 -> n2 => endpoint(n1) = beginning(n2)
@@ -73,17 +73,22 @@ def get_bipartite_sets(G):
         return complexes, reactions
 
 def get_lpa_alpha_beta(alpha, beta, slow_indices, complex_dict=None, constant_dict=None):
+    try:
+        import numpy as np
+    except ImportError:
+        print 'This method requires NumPy. Please install NumPy first.'
+        raise
     # alpha: reactant stoichiometric coefficients of well-mixed system
     # beta: product stoichiometric coefficients of well-mixed system
     # slow_indices: indices of slow species in system; indices are row indices of alpha, beta
 
     # construct reverse dictionaries
     if complex_dict is not None:
-        complex_dict_reverse = {v:k for k,v in complex_dict.iteritems()}
+        complex_dict_reverse = invert_dict(complex_dict)
     else:
         complex_dict_reverse = None
     if constant_dict is not None:
-        constant_dict_reverse = {v:k for k,v in constant_dict.iteritems()}
+        constant_dict_reverse = invert_dict(constant_dict)
     else:
         constant_dict_reverse = None
 
@@ -207,11 +212,11 @@ def get_lpa_alpha_beta(alpha, beta, slow_indices, complex_dict=None, constant_di
         beta_lpa.append(beta_lpa_row)
 
     if complex_dict_reverse is not None:
-        complex_dict_lpa = {v:k for k,v in complex_dict_lpa_reverse.iteritems()}
+        complex_dict_lpa = invert_dict(complex_dict_lpa_reverse)
     else:
         complex_dict_lpa = None
     if constant_dict_reverse is not None:
-        constant_dict_lpa = {v:k for k,v in constant_dict_lpa_reverse.iteritems()}
+        constant_dict_lpa = invert_dict(constant_dict_lpa_reverse)
     else:
         constant_dict_lpa = None
 
@@ -237,11 +242,15 @@ def get_path_graph(sc):
             paths.add((path[0],path[1],path[2],path[3]))
         for path in sc[substance]['n_paths']:
             paths.add((path[0],path[1],path[2],path[3]))
-            paths.add((path[2],path[1],path[0],path[3]))
+            if (path[2], path[1]) in sc[path[2]]['edges']: # only add reverse direction if corresponding edge exists in this fragment
+                paths.add((path[2],path[1],path[0],path[3]))
     paths = list(paths)
 
     # collect all starting and end points of paths
-    path_starts = {key:[] for key in sc.keys()}#dict.fromkeys(sc.keys(),[])
+    path_starts = {}
+    for key in sc.keys():
+        path_starts[key] = []
+
  #   path_ends = dict.fromkeys(sc.keys(),[])
 
     for path in paths:
