@@ -1,6 +1,5 @@
 import re
-
-import numpy as np
+from gratelpy.utils import invert_dict
 
 def fgsl(v):
     return format_gsl(v)
@@ -109,15 +108,18 @@ def print_gsl_header(header_type, mechanism_file, alpha, beta, complex_dict=None
 
 
 def print_jac_from_alpha_beta(basename, alpha, beta, complex_dict=None, constant_dict=None, gsl=False, gsl_conservation_rules = None):
+    # conservation rules expected as
+    # [variable_to_be_replaced, new_constant, independent_variable_1, independent_variable_2, ...]
+    # variable_to_be_replaced = new_constant - independent_variable_1 - independent_variable_2 - ...
     
     # check if we were passed a 'reverse' dict and reverse it if needed
     if complex_dict is not None:
         if type(complex_dict.keys()[0]) is not type(int()):
-            complex_dict = {v:k for k,v in complex_dict.iteritems()}
+            complex_dict = invert_dict(complex_dict)
 
     if constant_dict is not None:
         if type(constant_dict.keys()[0]) is not type(int()):
-            constant_dict = {v:k for k,v in constant_dict.iteritems()}
+            constant_dict = invert_dict(constant_dict)
 
     # open file
     mechanism_file_name = basename+'.jac'
@@ -217,15 +219,18 @@ def print_jac_from_alpha_beta(basename, alpha, beta, complex_dict=None, constant
 
     
 def print_ode_from_alpha_beta(basename, alpha, beta, complex_dict=None, constant_dict=None, gsl=False, gsl_conservation_rules=None):
-
+    # conservation rules expected as
+    # [variable_to_be_replaced, new_constant, independent_variable_1, independent_variable_2, ...]
+    # variable_to_be_replaced = new_constant - independent_variable_1 - independent_variable_2 - ...
+    
     # check if we were passed a 'reverse' dict and reverse it if needed
     if complex_dict is not None:
         if type(complex_dict.keys()[0]) is not type(int()):
-            complex_dict = {v:k for k,v in complex_dict.iteritems()}
+            complex_dict = invert_dict(complex_dict)
 
     if constant_dict is not None:
         if type(constant_dict.keys()[0]) is not type(int()):
-            constant_dict = {v:k for k,v in constant_dict.iteritems()}
+            constant_dict = invert_dict(constant_dict)
     
     # open file
     mechanism_file_name = basename+'.ode'
@@ -484,12 +489,21 @@ def get_network_from_mechanism(filename, no_complexes):
     # check if we detected all rate constants
     if len(constants) != no_constants:
         raise Exception('number of rows in mechanism file counted: '+str(no_constants) + ' - constants detected: '+str(constants.keys()))
-
+    
     # create alpha and beta
-    alpha_transposed = np.array(alpha_transposed)
-    beta_transposed = np.array(beta_transposed)
-    alpha = np.transpose(alpha_transposed)
-    beta = np.transpose(beta_transposed)
+    # we do not need NumPy to transpose these
+    no_rows = len(alpha_transposed)
+    no_cols = len(alpha_transposed[0])
+    alpha = []
+    beta = []
+    for i in range(no_cols):
+        alpha_row = []
+        beta_row = []
+        for j in range(no_rows):
+            alpha_row.append(alpha_transposed[j][i])
+            beta_row.append(beta_transposed[j][i])
+        alpha.append(alpha_row)
+        beta.append(beta_row)
     
     return alpha, beta, complexes, constants, complexes_reverse, constants_reverse
 
